The class representing a canonical data dictionary
new()Initialize the DataDictionary with the data it documents and at least a mock data dictionary
DataDictionary$new(dataset_code, datadict)
dataset_codeuniquely identifies a dataset
datadictan existing datadict to be validated. It is expected the user does the initial work of at least a basic data dictionary.
validate_datadict()DataDictionary$validate_datadict(datadict)
document_data()DataDictionary$document_data(data, only_new = TRUE)
clone()The objects of this class are cloneable with this method.
DataDictionary$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.